==> prestashop_1.4.4.1.zip: prestashop/modules/cashticket/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_330bf06fb43e715e5d03c9fd016df4cd'] = 'Il pagamento non è stato ancora accettato:';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_486cb12e1ec3c8b28b80a8eb9f2db2c0'] = 'Accetta il pagamento';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_e9b3579d8e877bcd29ab436f2ef87cc8'] = 'Emetti il pagamento';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Il tuo ordine sul';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'è completo.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_91675397c13245179e4bc959514fc2ca'] = 'Hai scelto il';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2c987f462c2ab7fc63e061e871e6a97d'] = 'metodo.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_e6dc7945b557a1cd949bea92dd58963e'] = 'Il tuo ordine verrà inviato al più presto.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Per eventuali domande o per ulteriori informazioni, contatta la nostra';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'assistenza clienti';
$_MODULE['<{cashticket}prestashop>disposition-error_393988def796f78c4b673b90548f3afa'] = 'Stato della disposizione non valido';
$_MODULE['<{cashticket}prestashop>disposition-error_5db89f2bf67f2c7dbd86cac101c3c1b8'] = '. Non sei autorizzato ad effettuare il pagamento.';
$_MODULE['<{cashticket}prestashop>payment_da9c72b9e543135f3f59e3c8ac68ef35'] = 'Paga con';
$_MODULE['<{cashticket}prestashop>cashticket_4512bbd48918c03027387a6c8e911342'] = 'CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_21d3d890383dc93343ce57c221ce5b3d'] = 'Si accettano pagamenti tramite CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_bed51f5187d4bf98e08f44d93f3098d9'] = 'Disposizione creata. In attesa di addebito.';
$_MODULE['<{cashticket}prestashop>cashticket_894f0316a71ef67255369c82bf8a0e5b'] = 'Stato della disposizione non valido:';
$_MODULE['<{cashticket}prestashop>cashticket_c1c25198721552ea8ddd963c7278d4ab'] = 'Si è verificato un errore durante il pagamento:';
$_MODULE['<{cashticket}prestashop>cashticket_36ec50c0e914dd2fb48a1b27540512ce'] = 'Pagamento accettato.';
$_MODULE['<{cashticket}prestashop>cashticket_d6ca44369efe062cec0c09f392465f55'] = 'Questo modulo richiede che l\'estensione curl di PHP funzioni correttamente.';
$_MODULE['<{cashticket}prestashop>cashticket_fe9da2c5e2e153d2415b4cd5d91166a4'] = 'non è scrivibile!';
$_MODULE['<{cashticket}prestashop>cashticket_139cfa047b503ac5b9a6b4b1b03090ad'] = 'Questo modulo richiede la valuta:';
$_MODULE['<{cashticket}prestashop>cashticket_ef5d34b04ab3b2eaaf7cb9d0f51267ed'] = 'Configura ogni valuta singolarmente:';
$_MODULE['<{cashticket}prestashop>cashticket_69a530f77bb82f704b9ff5e18bbdea6f'] = '(Il modulo di pagamento non sarà visualizzato per i clienti che utilizzano una valuta non configurata.)';
$_MODULE['<{cashticket}prestashop>cashticket_7d3d009ac1b9d1e826a1a72c046ea635'] = 'Configurazione in';
$_MODULE['<{cashticket}prestashop>cashticket_229a7ec501323b94db7ff3157a7623c9'] = 'ID commerciante';
$_MODULE['<{cashticket}prestashop>cashticket_845314022daaa8b665e718c4b51738aa'] = 'Certificato keyring';
$_MODULE['<{cashticket}prestashop>cashticket_a01813de717585e9ac9458bbfc54485a'] = 'Keyring PW';
$_MODULE['<{cashticket}prestashop>cashticket_254f642527b45bc260048e30704edb39'] = 'Configurazione';
$_MODULE['<{cashticket}prestashop>cashticket_0ba29c6a1afacf586b03a26162c72274'] = 'Ambiente';
$_MODULE['<{cashticket}prestashop>cashticket_1d5ad3d37f236c9eebda547690373bba'] = 'Tipo di business';
$_MODULE['<{cashticket}prestashop>cashticket_b024248d9fecf8c34f629e89a9fb93b4'] = 'Pagamento immediato';
$_MODULE['<{cashticket}prestashop>cashticket_c80a51a60c5ee43553c3881459b8f431'] = 'Aggiorna la configurazione';
$_MODULE['<{cashticket}prestashop>cashticket_86f28c996ee9075e9fc9a97dc8d5f254'] = 'Devi fornire un certificato per ID COMMERCIANTE';
$_MODULE['<{cashticket}prestashop>cashticket_bbced877c13c763f0141ff906c8ed0e5'] = 'File non valido';
$_MODULE['<{cashticket}prestashop>cashticket_97e5793f511c7930ab295997cb28553a'] = 'ID commerciante non valido';
$_MODULE['<{cashticket}prestashop>cashticket_c888438d14855d7d96a2724ee9c306bd'] = 'Impostazioni aggiornate';
$_MODULE['<{cashticket}prestashop>cashticket_a98658e7f6aa80803873db3a3e982f4d'] = 'Il file è stato parzialmente caricato';
$_MODULE['<{cashticket}prestashop>cashticket_d2bbf245e9591814fe994df3cae95964'] = 'Il file è vuoto';
$_MODULE['<{cashticket}prestashop>cashticket_ebbe99d835c79ead89db1b2b9e4fe70f'] = 'Operazione non avviata a causa di problemi di connessione. Se il problema persiste, si prega di contattare il nostro supporto.';
$_MODULE['<{cashticket}prestashop>cashticket_99f6765a05b697eb78e8c2e5e228f2fc'] = 'Disposizione consumata';
$_MODULE['<{cashticket}prestashop>cashticket_c3e260f43a99b6fd907538953fe700d0'] = 'Disposizione emessa';
$_MODULE['<{cashticket}prestashop>cashticket_12879ec2c367483dd59ef7442178d124'] = 'Si è verificato un errore durante l\'emissione';
$_MODULE['<{cashticket}prestashop>cashticket_d929c5e5e5643c622400e837914206da'] = 'Accetta pagamenti prepagati nel tuo shop online. Tutto ciò che è richiesto per pagare in un negozio web è codice PIN a 16 cifre di Cash-Ticket. In questo modo, i consumatori possono effettuare pagamenti online senza carta di credito o un conto bancario.';
$_MODULE['<{cashticket}prestashop>cashticket_d59048f21fd887ad520398ce677be586'] = 'Per saperne di più';
$_MODULE['<{cashticket}prestashop>cashticket_930320ced1b8c376237844049b570a7f'] = 'Si verificato un errore, controlla i messaggi per maggiori informazioni';
$_MODULE['<{cashticket}prestashop>cashticket_a9ced76f2dd6907220fa95b3a136b04a'] = 'Importo non valido';

?>

==> prestashop_1.5.0.1.zip: prestashop/modules/cashticket/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{cashticket}prestashop>prepaidservices_3e8e30e75887d2f3b02da669ebd5b380'] = 'Un certificato è stato trovato per questa configurazione';
$_MODULE['<{cashticket}prestashop>prepaidservices_515f3d11e66f6fc5f7bb453e6030241a'] = 'Una password è già stato salvato';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_330bf06fb43e715e5d03c9fd016df4cd'] = 'Il pagamento non è stato ancora accettato:';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_486cb12e1ec3c8b28b80a8eb9f2db2c0'] = 'Accetta il pagamento';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_e9b3579d8e877bcd29ab436f2ef87cc8'] = 'Emetti il pagamento';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Il tuo ordine sul';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'è completo.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_91675397c13245179e4bc959514fc2ca'] = 'Hai scelto il';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2c987f462c2ab7fc63e061e871e6a97d'] = 'metodo.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_e6dc7945b557a1cd949bea92dd58963e'] = 'Il tuo ordine verrà inviato al più presto.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Per eventuali domande o per ulteriori informazioni, contatta la nostra';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'assistenza clienti';
$_MODULE['<{cashticket}prestashop>cashticket_4512bbd48918c03027387a6c8e911342'] = 'CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_21d3d890383dc93343ce57c221ce5b3d'] = 'Si accettano pagamenti tramite CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_bed51f5187d4bf98e08f44d93f3098d9'] = 'Disposizione creata. In attesa di addebito.';
$_MODULE['<{cashticket}prestashop>cashticket_894f0316a71ef67255369c82bf8a0e5b'] = 'Stato della disposizione non valido:';
$_MODULE['<{cashticket}prestashop>cashticket_c1c25198721552ea8ddd963c7278d4ab'] = 'Si è verificato un errore durante il pagamento:';
$_MODULE['<{cashticket}prestashop>cashticket_36ec50c0e914dd2fb48a1b27540512ce'] = 'Pagamento accettato.';
$_MODULE['<{cashticket}prestashop>cashticket_d6ca44369efe062cec0c09f392465f55'] = 'Questo modulo richiede che l\'estensione curl di PHP funzioni correttamente.';
$_MODULE['<{cashticket}prestashop>cashticket_fe9da2c5e2e153d2415b4cd5d91166a4'] = 'non è scrivibile!';
$_MODULE['<{cashticket}prestashop>cashticket_139cfa047b503ac5b9a6b4b1b03090ad'] = 'Questo modulo richiede la valuta:';
$_MODULE['<{cashticket}prestashop>cashticket_ef5d34b04ab3b2eaaf7cb9d0f51267ed'] = 'Configura ogni valuta singolarmente:';
$_MODULE['<{cashticket}prestashop>cashticket_69a530f77bb82f704b9ff5e18bbdea6f'] = '(Il modulo di pagamento non sarà visualizzato per i clienti che utilizzano una valuta non configurata.)';
$_MODULE['<{cashticket}prestashop>cashticket_7d3d009ac1b9d1e826a1a72c046ea635'] = 'Configurazione in';
$_MODULE['<{cashticket}prestashop>cashticket_229a7ec501323b94db7ff3157a7623c9'] = 'ID commerciante';
$_MODULE['<{cashticket}prestashop>cashticket_845314022daaa8b665e718c4b51738aa'] = 'Certificato keyring';
$_MODULE['<{cashticket}prestashop>cashticket_a01813de717585e9ac9458bbfc54485a'] = 'Keyring PW';
$_MODULE['<{cashticket}prestashop>cashticket_254f642527b45bc260048e30704edb39'] = 'Configurazione';
$_MODULE['<{cashticket}prestashop>cashticket_0ba29c6a1afacf586b03a26162c72274'] = 'Ambiente';
$_MODULE['<{cashticket}prestashop>cashticket_1d5ad3d37f236c9eebda547690373bba'] = 'Tipo di business';
$_MODULE['<{cashticket}prestashop>cashticket_b024248d9fecf8c34f629e89a9fb93b4'] = 'Pagamento immediato';
$_MODULE['<{cashticket}prestashop>cashticket_c80a51a60c5ee43553c3881459b8f431'] = 'Aggiorna la configurazione';
$_MODULE['<{cashticket}prestashop>cashticket_86f28c996ee9075e9fc9a97dc8d5f254'] = 'Devi fornire un certificato per ID COMMERCIANTE';
$_MODULE['<{cashticket}prestashop>cashticket_bbced877c13c763f0141ff906c8ed0e5'] = 'File non valido';
$_MODULE['<{cashticket}prestashop>cashticket_97e5793f511c7930ab295997cb28553a'] = 'ID commerciante non valido';
$_MODULE['<{cashticket}prestashop>cashticket_c888438d14855d7d96a2724ee9c306bd'] = 'Impostazioni aggiornate';
$_MODULE['<{cashticket}prestashop>cashticket_a98658e7f6aa80803873db3a3e982f4d'] = 'Il file è stato parzialmente caricato';
$_MODULE['<{cashticket}prestashop>cashticket_d2bbf245e9591814fe994df3cae95964'] = 'Il file è vuoto';
$_MODULE['<{cashticket}prestashop>cashticket_ebbe99d835c79ead89db1b2b9e4fe70f'] = 'Operazione non avviata a causa di problemi di connessione. Se il problema persiste, si prega di contattare il nostro supporto.';
$_MODULE['<{cashticket}prestashop>cashticket_99f6765a05b697eb78e8c2e5e228f2fc'] = 'Disposizione consumata';
$_MODULE['<{cashticket}prestashop>cashticket_c3e260f43a99b6fd907538953fe700d0'] = 'Disposizione emessa';
$_MODULE['<{cashticket}prestashop>cashticket_12879ec2c367483dd59ef7442178d124'] = 'Si è verificato un errore durante l\'emissione';
$_MODULE['<{cashticket}prestashop>cashticket_d929c5e5e5643c622400e837914206da'] = 'Accetta pagamenti prepagati nel tuo shop online. Tutto ciò che è richiesto per pagare in un negozio web è codice PIN a 16 cifre di Cash-Ticket. In questo modo, i consumatori possono effettuare pagamenti online senza carta di credito o un conto bancario.';
$_MODULE['<{cashticket}prestashop>cashticket_d59048f21fd887ad520398ce677be586'] = 'Per saperne di più';
$_MODULE['<{cashticket}prestashop>cashticket_930320ced1b8c376237844049b570a7f'] = 'Si verificato un errore, controlla i messaggi per maggiori informazioni';
$_MODULE['<{cashticket}prestashop>cashticket_a9ced76f2dd6907220fa95b3a136b04a'] = 'Importo non valido';
$_MODULE['<{cashticket}prestashop>disposition-error_393988def796f78c4b673b90548f3afa'] = 'Stato della disposizione non valido';
$_MODULE['<{cashticket}prestashop>disposition-error_5db89f2bf67f2c7dbd86cac101c3c1b8'] = '. Non sei autorizzato ad effettuare il pagamento.';
$_MODULE['<{cashticket}prestashop>payment_da9c72b9e543135f3f59e3c8ac68ef35'] = 'Paga con';
